weaviate.collections.classes package
====================================

.. automodule:: weaviate.collections.classes
   :members:
   :undoc-members:
   :show-inheritance:

Submodules
----------

weaviate.collections.classes.aggregate module
---------------------------------------------

.. automodule:: weaviate.collections.classes.aggregate
   :members:
   :undoc-members:
   :show-inheritance:

weaviate.collections.classes.batch module
-----------------------------------------

.. automodule:: weaviate.collections.classes.batch
   :members:
   :undoc-members:
   :show-inheritance:

weaviate.collections.classes.config module
------------------------------------------

.. automodule:: weaviate.collections.classes.config
   :members:
   :undoc-members:
   :show-inheritance:

weaviate.collections.classes.config\_methods module
---------------------------------------------------

.. automodule:: weaviate.collections.classes.config_methods
   :members:
   :undoc-members:
   :show-inheritance:

weaviate.collections.classes.data module
----------------------------------------

.. automodule:: weaviate.collections.classes.data
   :members:
   :undoc-members:
   :show-inheritance:

weaviate.collections.classes.filters module
-------------------------------------------

.. automodule:: weaviate.collections.classes.filters
   :members:
   :undoc-members:
   :show-inheritance:

weaviate.collections.classes.grpc module
----------------------------------------

.. automodule:: weaviate.collections.classes.grpc
   :members:
   :undoc-members:
   :show-inheritance:

weaviate.collections.classes.internal module
--------------------------------------------

.. automodule:: weaviate.collections.classes.internal
   :members:
   :undoc-members:
   :show-inheritance:

weaviate.collections.classes.orm module
---------------------------------------

.. automodule:: weaviate.collections.classes.orm
   :members:
   :undoc-members:
   :show-inheritance:

weaviate.collections.classes.tenants module
-------------------------------------------

.. automodule:: weaviate.collections.classes.tenants
   :members:
   :undoc-members:
   :show-inheritance:

weaviate.collections.classes.types module
-----------------------------------------

.. automodule:: weaviate.collections.classes.types
   :members:
   :undoc-members:
   :show-inheritance:
